# defaults
###########
guiToolkit.default <- 'RGtk2'
wpp.year.default <- 2010

# color.main <- "blanchedalmond"
# color.button <- "bisque1"
# color.nb.inactive <- "beige"

# color.main <- "#4B92DB"
# color.button <- "dodgerblue"
# color.nb.inactive <- "steelblue1"

# color.main <- "lightskyblue1"
# color.button <- "lightskyblue2"
# color.nb.inactive <- "lightblue1"

# color.main <- "aliceblue"
# color.button <- "azure2"
# color.nb.inactive <- "azure1"

# color.main <- "grey91"
# color.button <- "grey91"
# color.nb.inactive <- "grey91"

# color.main <- "bisque1"
# color.button <- "bisque1"
# color.nb.inactive <- "bisque1"

# color.main <- "wheat2"
# color.button <- "wheat2"
# color.nb.inactive <- "wheat2"

# color.main <- "antiquewhite"
# color.button <- "antiquewhite"
# color.nb.inactive <- "antiquewhite"

# color.main <- "antiquewhite2"
# color.button <- "antiquewhite2"
# color.nb.inactive <- "antiquewhite2"

color.main <- "bisque2"
color.button <- "bisque2"
color.nb.inactive <- "bisque2"